@@ -31,22 +31,32 @@ XLinkObj::~XLinkObj ()
     delete (path);
     delete (ctrl_p0);
     delete (ctrl_p1);
-    delete (ctrl_l0);
-    delete (ctrl_l1);
+    delete (pointerEnd);
+    delete (pointerBegin);
 }
 
 
 void XLinkObj::init () 
 {
     visBranch=NULL;
+
     stateVis=Hidden;
 
     QPen pen=link->getPen();
 
-
     path=scene()->addPath (QPainterPath(), pen, Qt::NoBrush);	
     path->setZValue (dZ_XLINK);
 
+    pointerBegin = new ArrowObj(this);
+    pointerBegin->setPen( pen );
+    pointerBegin->setUseFixedLength( true );
+    pointerBegin->setFixedLength( 0 );
+
+    pointerEnd = new ArrowObj(this);
+    pointerEnd->setPen( pen );
+    pointerEnd->setUseFixedLength( true );
+    pointerEnd->setFixedLength( 0 );
+
     pen.setStyle (Qt::SolidLine);
     poly=scene()->addPolygon (QPolygonF(), pen, pen.color());	
     poly->setZValue (dZ_XLINK);
@@ -67,8 +77,6 @@ void XLinkObj::init ()
     beginOrient=endOrient=LinkableMapObj::UndefinedOrientation;
     pen.setWidth (1);
     pen.setStyle (Qt::DashLine);
-    ctrl_l0=scene()->addLine(0,0,0,0, pen);
-    ctrl_l1=scene()->addLine(0,0,0,0, pen);
 
     curSelection=Unselected;
 
@@ -91,6 +99,36 @@ QPointF XLinkObj::getAbsPos()
     }
 }
 
+void XLinkObj::setStyleBegin(const QString &s)
+{
+    pointerBegin->setStyleEnd( s );
+}
+
+void XLinkObj::setStyleBegin(ArrowObj::OrnamentStyle os)
+{
+    pointerBegin->setStyleEnd( os );
+}
+
+ArrowObj::OrnamentStyle XLinkObj::getStyleBegin()
+{
+    return pointerBegin->getStyleEnd();
+}
+
+void XLinkObj::setStyleEnd(const QString &s)
+{
+    pointerEnd->setStyleEnd( s );
+}
+
+void XLinkObj::setStyleEnd(ArrowObj::OrnamentStyle os)
+{
+    pointerEnd->setStyleEnd( os );
+}
+
+ArrowObj::OrnamentStyle XLinkObj::getStyleEnd()
+{
+    return pointerEnd->getStyleEnd();
+}
+
 QPointF XLinkObj::getBeginPos()
 {
     return beginPos;
@@ -173,6 +211,8 @@ void XLinkObj::updateXLink()
 	if (!bo) return;
 
 	a=b=bo->getChildRefPos();
+
+
 	if (bo->getOrientation()==LinkableMapObj::RightOfCenter)
 	{
 	    b.setX (b.x() + 2*arrowSize);
@@ -205,8 +245,16 @@ void XLinkObj::updateXLink()
 	// If a link is just drawn in the editor,
 	// we have already a beginBranch
 	if (beginBO) beginPos=beginBO->getChildRefPos();
-
 	if (endBO) endPos=endBO->getChildRefPos();
+
+        if (beginBO && endBO)
+        {
+            pointerBegin->move(beginPos + c0 );
+            pointerBegin->setEndPoint(beginPos);
+
+            pointerEnd->move(endPos + c1 );
+            pointerEnd->setEndPoint(endPos);
+        }
     }
 
     // Update control points for bezier
@@ -224,7 +272,12 @@ void XLinkObj::updateXLink()
     path->setPen (pen);
     poly->setBrush (pen.color() );
     
+    pointerBegin->setPen( pen );
+    pointerEnd->setPen( pen );
+
     pen.setStyle (Qt::SolidLine);
+
+
     ctrl_p0->setRect (
 	beginPos.x() + c0.x() - pointRadius/2, beginPos.y() + c0.y() - pointRadius/2,
 	pointRadius, pointRadius );
@@ -237,16 +290,6 @@ void XLinkObj::updateXLink()
     ctrl_p1->setPen (pen);
     ctrl_p1->setBrush (pen.color() );
 
-    pen.setStyle (Qt::DashLine);
-    ctrl_l0->setLine ( 
-	beginPos.x(), beginPos.y(),
-	c0.x() + beginPos.x(), c0.y() + beginPos.y() );
-    ctrl_l0->setPen (pen);
-    ctrl_l1->setLine ( 
-	endPos.x(), endPos.y(),
-	c1.x() + endPos.x(), c1.y() + endPos.y() );
-    ctrl_l1->setPen (pen);
-	
     BranchItem *bi_begin=link->getBeginBranch();
     BranchItem *bi_end  =link->getEndBranch();
     if (bi_begin && bi_end && link->getState()==Link::activeXLink)
@@ -270,37 +313,55 @@ void XLinkObj::calcBBoxSize()
 
 void XLinkObj::setVisibility (bool b)
 {
+    if (stateVis==FullShowControls)
+    {
+	ctrl_p0->show();
+	ctrl_p1->show();
+        pointerBegin->setUseFixedLength( false );
+        pointerEnd->setUseFixedLength( false );
+    } else
+    {
+	ctrl_p0->hide();
+	ctrl_p1->hide();
+        pointerBegin->setUseFixedLength( true );
+        pointerBegin->setFixedLength( 0 );
+        pointerEnd->setUseFixedLength( true );
+        pointerEnd->setFixedLength( 0 );
+    }
+
     MapObj::setVisibility (b);
     if (b)
     {
-	path->show();
-	if (stateVis==Part) 
+	if (stateVis==OnlyBegin) 
 	{
 	    path->hide();
 	    poly->show();
+            pointerBegin->hide();
+            pointerEnd->hide();
 	}
-	else	
+	else if (stateVis==OnlyEnd)
+	{
+	    path->hide();
+	    poly->show();
+            pointerBegin->hide();
+            pointerEnd->hide();
+	}
+        else
+        {
+            path->show();
 	    poly->hide();
+            pointerBegin->show();
+            pointerEnd->show();
+        }
     }	
     else
     {
 	poly->hide();
 	path->hide();
+        pointerBegin->hide();
+        pointerEnd->hide();
     }	
 
-    if (stateVis==FullShowControls)
-    {
-	ctrl_p0->show();
-	ctrl_p1->show();
-	ctrl_l0->show();
-	ctrl_l1->show();
-    } else
-    {
-	ctrl_p0->hide();
-	ctrl_p1->hide();
-	ctrl_l0->hide();
-	ctrl_l1->hide();
-    }
 }
 
 void XLinkObj::setVisibility ()
@@ -333,10 +394,15 @@ void XLinkObj::setVisibility ()
 	    {	// Just one end is visible, draw a symbol that shows
 		// that there is a link to a scrolled branch
 		if (beginBO->isVisibleObj())
+                {
+                    stateVis=OnlyBegin;
 		    visBranch=beginBI;
+                }
 		else
+                {
 		    visBranch=endBI;
-		stateVis=Part;
+                    stateVis=OnlyEnd;
+                }
 		setVisibility (true);
 	    }
 	}
@@ -403,7 +469,7 @@ bool XLinkObj::isInClickBox (const QPointF &p)
             // Enable selecting the path, when a ctrl point is already selected
             if (!b && curSelection!=Unselected && clickPath.intersects (r)) b=true;
 	    break;
-	case Part:    
+	case OnlyBegin || OnlyEnd:    
 	    // not selected, only partially visible
 	    if (poly->boundingRect().contains(p) ) 
 		b=true;
@@ -436,4 +502,3 @@ QPainterPath XLinkObj::getClickPath()  // also needs mirroring if oriented left.
 	    break;
     }
 }
-
